/* 

   Geeks Artificial Neural Network (G.A.N.N) - Exit
   
   Copyright GNU/GPL 2005-2006 George Delaportas (qtgeo)
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

*/



#if defined __GMAIN__
#define __GEXIT__

//Geeks Exit (Function)
void GExit(int ExitCode,char *ExitMsg)

{

    printf("%s\n",ExitMsg);
    printf("G.A.N.N Terminated (Code:%i)\n",ExitCode);
    
    exit(ExitCode);

}

#endif

/* ------------------------------------------------------------------------ */
